try:
    from ._noxfile import build_check, build_dist, tests
except ImportError as exc:
    raise RuntimeError("The 'calcipy[nox]' extras are missing") from exc

__all__ = ('build_check', 'build_dist', 'tests')



"""Stale Packages CLI."""

from invoke.context import Context

from calcipy.check_for_stale_packages import check_for_stale_packages as cfsp
from calcipy.cli import task


@task(
    default=True,
    help={
        'stale_months': 'Cutoff in months for when a package may be stale enough to be a risk',
    },
)
def check_for_stale_packages(ctx: Context, *, stale_months: int = 48) -> None:  # noqa: ARG001
    """Identify stale dependencies."""
    cfsp(stale_months=stale_months)



try:
    from ._check_for_stale_packages import check_for_stale_packages
except ImportError as exc:
    raise RuntimeError("The 'calcipy[stale]' extras are missing") from exc

__all__ = ('check_for_stale_packages',)



try:
    from ._writer import write_autoformatted_md_sections
except ImportError as exc:
    raise RuntimeError("The 'calcipy[doc]' extras are missing") from exc

__all__ = ('write_autoformatted_md_sections',)
